@@ -35,12 +35,9 @@
 #include "krulerconfig.h"
 
 #ifdef KRULER_HAVE_X11
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
-#include <private/qtx11extras_p.h>
-#endif
+#include <KX11Extras>
 #include <netwm.h>
+#include <private/qtx11extras_p.h>
 #endif
 
 #include "kruler.h"
@@ -85,7 +82,11 @@ KLineal::KLineal(QWidget *parent)
     mWayland = KWindowSystem::isPlatformWayland();
 
     setAttribute(Qt::WA_TranslucentBackground);
-    KWindowSystem::setType(winId(), NET::Override); // or NET::Normal
+#ifdef KRULER_HAVE_X11
+    if (KWindowSystem::isPlatformX11()) {
+        KX11Extras::setType(winId(), NET::Override); // or NET::Normal
+    }
+#endif
 
     setWindowTitle(i18nc("@title:window", "KRuler"));
 
@@ -197,7 +198,7 @@ void KLineal::createSystemTray()
     mMenu->addAction(mCloseAction);
 
     if (!mTrayIcon) {
-        mTrayIcon = new KRulerSystemTray(QStringLiteral("kruler"), this, mActionCollection);
+        mTrayIcon = new KRulerSystemTray(QStringLiteral("kruler-symbolic"), this, mActionCollection);
         mTrayIcon->setCategory(KStatusNotifierItem::ApplicationStatus);
     }
 }
@@ -579,11 +580,7 @@ void KLineal::mousePressEvent(QMouseEvent *e)
 
 void KLineal::mouseMoveEvent(QMouseEvent *e)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    mCursorPos = e->pos();
-#else
     mCursorPos = e->position().toPoint();
-#endif
     if (beginRect().contains(mCursorPos) || endRect().contains(mCursorPos)) {
         setCursor(resizeCursor());
     } else {
